import React from "react";
import classNames from "classnames";

import Post from "./Post";

const PostList = ({
  className,
  items,
  onLike,
  onDislike,
  onHide,
  onBanUser,
  onAnnounceProcedureProposal,
  onAcceptProcedureProposal,
  onRejectProcedureProposal,
  dimArchived,
}) => {
  const buildHandler = (responderFn) => (post) => (evt) => {
    evt.preventDefault();
    responderFn(post);
  };

  const onPostLike = buildHandler(onLike);
  const onPostDislike = buildHandler(onDislike);
  const onPostHide = buildHandler(onHide);
  const onPostBanUser = buildHandler(onBanUser);
  const onPostAnnounceProcedureProposal = buildHandler(
    onAnnounceProcedureProposal
  );
  const onPostAcceptProcedureProposal = buildHandler(onAcceptProcedureProposal);
  const onPostRejectProcedureProposal = buildHandler(onRejectProcedureProposal);

  return (
    <div className={classNames("space-y-px", className)}>
      {items
        .filter((item) => !item.hidden)
        .map((item) => (
          <Post
            key={item.id}
            datetime={item.datetime}
            author={item.author}
            type={item.type}
            state={item.state}
            content={item.content}
            ranking={item.ranking}
            historyLog={item.historyLog}
            seen={item.seen}
            archived={item.archived}
            displayActions={true}
            dimIfArchived={dimArchived}
            onLike={onPostLike(item)}
            onDislike={onPostDislike(item)}
            onHide={onPostHide(item)}
            onBanUser={onPostBanUser(item)}
            onAnnounceProcedureProposal={onPostAnnounceProcedureProposal(item)}
            onAcceptProcedureProposal={onPostAcceptProcedureProposal(item)}
            onRejectProcedureProposal={onPostRejectProcedureProposal(item)}
          />
        ))}
    </div>
  );
};

export default PostList;
